=======
History
=======

0.7.2 (2017-08-22)
------------------
* Add new ScreenBase() arg to allow over-ride of default behavior to wipe the HTML pop-up area afer each screen passes user data validation

0.7.1 (2017-08-21)
------------------
* changed session.display_screen() to re-raise a CancelButtonPressed exception to be handled by the caller

0.7.0 (2017-08-18)
------------------
* add new ScreenBase abstract base class